@@ -29,8 +29,7 @@ svn export "$REPOPATH"
 # Use composer only on newer versions that have a composer.json
 if [ -f "$TAG/composer.json" ]; then
     if [ ! -x composer.phar ]; then
-        echo "$0: Composerfile detected, but Composer not installed?" >&2
-        exit 1
+        curl -sS https://getcomposer.org/installer | php
     fi
 
     # Install dependencies (without vcs history or dev tools)
