@@ -26,7 +26,6 @@
  *
  * @author Olav Morken, UNINETT AS.
  * @package simpleSAMLphp
- * @version $Id$
  */
 class SimpleSAML_Auth_State {
 
@@ -160,7 +159,7 @@ class SimpleSAML_Auth_State {
 
 		/* Save state. */
 		$serializedState = serialize($state);
-		$session = SimpleSAML_Session::getInstance();
+		$session = SimpleSAML_Session::getSessionFromRequest();
 		$session->setData('SimpleSAML_Auth_State', $id, $serializedState, self::getStateTimeout());
 
 		SimpleSAML_Logger::debug('Saved state: ' . var_export($return, TRUE));
@@ -213,7 +212,7 @@ class SimpleSAML_Auth_State {
 
 		$sid = SimpleSAML_Utilities::parseStateID($id);
 
-		$session = SimpleSAML_Session::getInstance();
+		$session = SimpleSAML_Session::getSessionFromRequest();
 		$state = $session->getData('SimpleSAML_Auth_State', $sid['id']);
 
 		if ($state === NULL) {
@@ -242,7 +241,7 @@ class SimpleSAML_Auth_State {
 			 */
 
 			$msg = 'Wrong stage in state. Was \'' . $state[self::STAGE] .
-				'\', shoud be \'' . $stage . '\'.';
+				'\', should be \'' . $stage . '\'.';
 
 			SimpleSAML_Logger::warning($msg);
 
@@ -274,7 +273,7 @@ class SimpleSAML_Auth_State {
 
 		SimpleSAML_Logger::debug('Deleting state: ' . var_export($state[self::ID], TRUE));
 
-		$session = SimpleSAML_Session::getInstance();
+		$session = SimpleSAML_Session::getSessionFromRequest();
 		$session->deleteData('SimpleSAML_Auth_State', $state[self::ID]);
 	}
 
