@@ -5,7 +5,6 @@
  *
  * @author Olav Morken, UNINETT AS.
  * @package simpleSAMLphp
- * @version $Id$
  */
 class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception {
 
@@ -18,6 +17,14 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception {
 	private $errorCode;
 
 
+	/**
+	 * The http code.
+	 *
+	 * @var integer
+	 */
+	protected $httpCode = 500;
+
+
 	/**
 	 * The error title tag in dictionary.
 	 *
@@ -68,7 +75,7 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception {
 	 * @param mixed $errorCode  One of the error codes defined in the errors dictionary.
 	 * @param Exception $cause  The exception which caused this fatal error (if any).
 	 */
-	public function __construct($errorCode, Exception $cause = NULL) {
+	public function __construct($errorCode, Exception $cause = NULL, $httpCode = NULL) {
 		assert('is_string($errorCode) || is_array($errorCode)');
 
 		if (is_array($errorCode)) {
@@ -80,6 +87,10 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception {
 			$this->errorCode = $errorCode;
 		}
 
+		if (isset($httpCode)) {
+			$this->httpCode = $httpCode;
+		}
+
 		$moduleCode = explode(':', $this->errorCode, 2);
 		if (count($moduleCode) === 2) {
 			$this->module = $moduleCode[0];
@@ -153,7 +164,30 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception {
 	 * This should be overridden by subclasses who want a different return code than 500 Internal Server Error.
 	 */
 	protected function setHTTPCode() {
-		header('HTTP/1.0 500 Internal Server Error');
+		// Some mostly used HTTP codes.
+		$httpCodesMap = array(
+			400 => 'HTTP/1.0 400 Bad Request',
+			403 => 'HTTP/1.0 403 Forbidden',
+			404 => 'HTTP/1.0 404 Not Found',
+			405 => 'HTTP/1.0 405 Method Not Allowed',
+			500 => 'HTTP/1.0 500 Internal Server Error',
+			501 => 'HTTP/1.0 501 Method Not Implemented',
+			503 => 'HTTP/1.0 503 Service Temporarily Unavailable',
+		);
+
+		$httpCode = $this->httpCode;
+
+		if (function_exists('http_response_code')) {
+			http_response_code($httpCode);
+			return;
+		}
+
+		if (!array_key_exists($this->httpCode, $httpCodesMap)) {
+			$httpCode = 500;
+			SimpleSAML_Logger::warning('HTTP response code not defined: ' . var_export($this->httpCode, TRUE));
+		}
+
+		header($httpCodesMap[$httpCode]);
 	}
 
 
@@ -172,7 +206,7 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception {
 		SimpleSAML_Logger::error('Error report with id ' . $reportId . ' generated.');
 
 		$config = SimpleSAML_Configuration::getInstance();
-		$session = SimpleSAML_Session::getInstance();
+		$session = SimpleSAML_Session::getSessionFromRequest();
 
 		if (isset($_SERVER['HTTP_REFERER'])) {
 			$referer = $_SERVER['HTTP_REFERER'];
@@ -228,13 +262,14 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception {
 		$data['includeTemplate'] = $this->includeTemplate;
 
 		/* Check if there is a valid technical contact email address. */
-		if($config->getString('technicalcontact_email', 'na@example.org') !== 'na@example.org') {
+		if($config->getBoolean('errorreporting', TRUE) &&
+			$config->getString('technicalcontact_email', 'na@example.org') !== 'na@example.org') {
 			/* Enable error reporting. */
 			$baseurl = SimpleSAML_Utilities::getBaseURL();
 			$data['errorReportAddress'] = $baseurl . 'errorreport.php';
 		}
 
-		$session = SimpleSAML_Session::getInstance();
+		$session = SimpleSAML_Session::getSessionFromRequest();
 		$attributes = $session->getAttributes();
 		if (is_array($attributes) && array_key_exists('mail', $attributes) && count($attributes['mail']) > 0) {
 			$data['email'] = $attributes['mail'][0];
