@@ -6,7 +6,6 @@
  * This class implements the various functions used by IdP.
  *
  * @package simpleSAMLphp
- * @version $Id$
  */
 class SimpleSAML_IdP {
 
@@ -211,7 +210,7 @@ class SimpleSAML_IdP {
 
 		$association['core:IdP'] = $this->id;
 		
-		$session = SimpleSAML_Session::getInstance();
+		$session = SimpleSAML_Session::getSessionFromRequest();
 		$session->addAssociation($this->associationGroup, $association);
 	}
 
@@ -223,7 +222,7 @@ class SimpleSAML_IdP {
 	 */
 	public function getAssociations() {
 
-		$session = SimpleSAML_Session::getInstance();
+		$session = SimpleSAML_Session::getSessionFromRequest();
 		return $session->getAssociations($this->associationGroup);
 	}
 
@@ -236,7 +235,7 @@ class SimpleSAML_IdP {
 	public function terminateAssociation($assocId) {
 		assert('is_string($assocId)');
 
-		$session = SimpleSAML_Session::getInstance();
+		$session = SimpleSAML_Session::getSessionFromRequest();
 		$session->terminateAssociation($this->associationGroup, $assocId);
 	}
 
@@ -260,7 +259,7 @@ class SimpleSAML_IdP {
 		assert('is_callable($state["Responder"])');
 
 		if (isset($state['core:SP'])) {
-			$session = SimpleSAML_Session::getInstance();
+			$session = SimpleSAML_Session::getSessionFromRequest();
 			$session->setData('core:idp-ssotime', $state['core:IdP'] . ';' . $state['core:SP'],
 				time(), SimpleSAML_Session::DATA_TIMEOUT_LOGOUT);
 		}
@@ -292,7 +291,7 @@ class SimpleSAML_IdP {
 		}
 
 		if (isset($state['core:SP'])) {
-			$session = SimpleSAML_Session::getInstance();
+			$session = SimpleSAML_Session::getSessionFromRequest();
 			$previousSSOTime = $session->getData('core:idp-ssotime', $state['core:IdP'] . ';' . $state['core:SP']);
 			if ($previousSSOTime !== NULL) {
 				$state['PreviousSSOTimestamp'] = $previousSSOTime;
@@ -379,8 +378,6 @@ class SimpleSAML_IdP {
 		if (isset($state['ForceAuthn']) && (bool)$state['ForceAuthn']) {
 			/* Force authentication is in effect. */
 			$needAuth = TRUE;
-		} elseif (isset($state['saml:IDPList']) && sizeof($state['saml:IDPList']) > 0) {
-			$needAuth = !in_array($this->authSource->getAuthData('saml:sp:IdP'), $state['saml:IDPList'], TRUE);
 		} else {
 			$needAuth = !$this->isAuthenticated();
 		}
