@@ -384,7 +384,6 @@ class SimpleSAML_Metadata_SAMLParser {
 		 * Add organizational metadata
 		 */
 		if (!empty($this->organizationName)) {
-			$ret['name'] = $this->organizationName;
 			$ret['description'] = $this->organizationName;
 			$ret['OrganizationName'] = $this->organizationName;
 		}
@@ -636,6 +635,11 @@ class SimpleSAML_Metadata_SAMLParser {
 		/* Add extensions. */
 		$this->addExtensions($ret, $spd);
 
+		// prioritize mdui:DisplayName as the name if available
+		if (!empty($ret['UIInfo']['DisplayName'])) {
+			$ret['name'] = $ret['UIInfo']['DisplayName'];
+		}
+
 		return $ret;
 	}
 
@@ -678,7 +682,7 @@ class SimpleSAML_Metadata_SAMLParser {
 
 		/* Enable redirect.sign if WantAuthnRequestsSigned is enabled. */
 		if ($idp['WantAuthnRequestsSigned']) {
-			$ret['redirect.sign'] = TRUE;
+			$ret['sign.authnrequest'] = TRUE;
 		}
 
 		/* Find the SSO service endpoint. */
@@ -700,6 +704,11 @@ class SimpleSAML_Metadata_SAMLParser {
 		/* Add extensions. */
 		$this->addExtensions($ret, $idp);
 
+		// prioritize mdui:DisplayName as the name if available
+		if (!empty($ret['UIInfo']['DisplayName'])) {
+			$ret['name'] = $ret['UIInfo']['DisplayName'];
+		}
+
 		return $ret;
 	}
 
