@@ -13,12 +13,18 @@ function consentSimpleAdmin_hook_sanitycheck(&$hookinfo) {
 	
 		// Parse consent config
 		$consent_storage = sspmod_consent_Store::parseStoreConfig($consentconfig->getValue('store'));
-		
-		// Get all consents for user
-		$stats = $consent_storage->getStatistics();
 
-		$hookinfo['info'][] = '[consentSimpleAdmin] Consent Storage connection OK.';	
-		
+		if (!is_callable(array($consent_storage, 'selftest'))) {
+			/* Doesn't support a selftest. */
+			return;
+		}
+		$testres = $consent_storage->selftest();
+		if ($testres) {
+			$hookinfo['info'][] = '[consentSimpleAdmin] Consent Storage selftest OK.';
+		} else {
+			$hookinfo['errors'][] = '[consentSimpleAdmin] Consent Storage selftest failed.';
+		}
+
 	} catch (Exception $e) {
 		$hookinfo['errors'][] = '[consentSimpleAdmin] Error connecting to storage: ' . $e->getMessage();	
 	}
