@@ -20,19 +20,18 @@ foreach($_COOKIE as $cookieName => $value) {
 	/* Delete the cookie. We delete it once without the secure flag and once with the secure flag. This
 	 * ensures that the cookie will be deleted in any case.
 	 */
-	setcookie($cookieName, '', time() - 24*60*60, $cookiePath);
+	SimpleSAML_Utilities::setCookie($cookieName, NULL, array('path' => $cookiePath, 'httponly' => FALSE), FALSE);
 }
 
 
 /* Find where we should go now. */
 if(array_key_exists('ReturnTo', $_REQUEST)) {
-	$returnTo = $_REQUEST['ReturnTo'];
+	$returnTo = SimpleSAML_Utilities::checkURLAllowed($_REQUEST['ReturnTo']);
 } else {
 	/* Return to the front page if no other destination is given. This is the same as the base cookie path. */
 	$returnTo = $cookiePath;
 }
 
 /* Redirect to destination. */
-SimpleSAML_Utilities::redirect($returnTo);
+SimpleSAML_Utilities::redirectTrustedURL($returnTo);
 
-?>
\ No newline at end of file
