@@ -4,7 +4,7 @@
 
 /* Load simpleSAMLphp, configuration */
 $config = SimpleSAML_Configuration::getInstance();
-$session = SimpleSAML_Session::getInstance();
+$session = SimpleSAML_Session::getSessionFromRequest();
 
 /* Check if valid local session exists.. */
 if ($config->getBoolean('admin.protectindexpage', false)) {
@@ -98,8 +98,8 @@ if (SimpleSAML_Module::isModuleEnabled('radius')) {
 $funcmatrix = array();
 $funcmatrix[] = array(
 	'required' => 'required', 
-	'descr' => 'PHP Version >= 5.2. You run: ' . phpversion(),
-	'enabled' => version_compare(phpversion(), '5.2', '>='));
+	'descr' => 'PHP Version >= 5.3. You run: ' . phpversion(),
+	'enabled' => version_compare(phpversion(), '5.3', '>='));
 foreach ($functionchecks AS $func => $descr) {
 	$funcmatrix[] = array('descr' => $descr[1], 'required' => $descr[0], 'enabled' => function_exists($func));
 }
