@@ -3,7 +3,7 @@
 
 /* Load simpleSAMLphp, configuration */
 $config = SimpleSAML_Configuration::getInstance();
-$session = SimpleSAML_Session::getInstance();
+$session = SimpleSAML_Session::getSessionFromRequest();
 
 /* Check if valid local session exists.. */
 if ($config->getBoolean('admin.protectindexpage', false)) {
@@ -33,7 +33,7 @@ $allLinks = array(
 );
 
 $links_welcome[] = array(
-	'href' => 'https://rnd.feide.no/view/simplesamlphpdocs',
+	'href' => 'https://simplesamlphp.org/docs/stable/',
 	'text' => '{core:frontpage:doc_header}',
 );
 
