@@ -2,7 +2,6 @@
 /*
  * @author Andreas Åkre Solberg <andreas.solberg@uninett.no>
  * @package simpleSAMLphp
- * @version $Id$
  */
 class sspmod_metarefresh_MetaLoader {
 
@@ -85,7 +84,13 @@ class sspmod_metarefresh_MetaLoader {
 			SimpleSAML_Logger::debug('Downloaded fresh copy');
 		}
 
-		$entities = $this->loadXML($data, $source);
+		try {
+			$entities = $this->loadXML($data, $source);
+		} catch(Exception $e) {
+			SimpleSAML_Logger::debug('XML parser error when parsing ' . $source['src'] . ' - attempting to re-use cached metadata');
+			$this->addCachedMetadata($source);
+			return;
+		}
 
 		foreach($entities as $entity) {
 
@@ -205,17 +210,13 @@ class sspmod_metarefresh_MetaLoader {
 	 */
 	private function loadXML($data, $source) {
 		$entities = array();
-		try {
-			$doc = new DOMDocument();
-			$res = $doc->loadXML($data);
-			if($res !== TRUE) {
-				throw new Exception('Failed to read XML from ' . $source['src']);
-			}
-			if($doc->documentElement ===  NULL) throw new Exception('Opened file is not an XML document: ' . $source['src']);
-			$entities = SimpleSAML_Metadata_SAMLParser::parseDescriptorsElement($doc->documentElement);
-		} catch(Exception $e) {
-			SimpleSAML_Logger::warning('metarefresh: Failed to retrieve metadata. ' . $e->getMessage());
+		$doc = new DOMDocument();
+		$res = $doc->loadXML($data);
+		if($res !== TRUE) {
+			throw new Exception('Failed to read XML from ' . $source['src']);
 		}
+		if($doc->documentElement ===  NULL) throw new Exception('Opened file is not an XML document: ' . $source['src']);
+		$entities = SimpleSAML_Metadata_SAMLParser::parseDescriptorsElement($doc->documentElement);
 		return $entities;
 	}
 
@@ -230,7 +231,8 @@ class sspmod_metarefresh_MetaLoader {
 				$this->stateFile,
 				"<?php\n/* This file was generated by the metarefresh module at ".$this->getTime() . ".\n".
 				" Do not update it manually as it will get overwritten. */\n".
-				'$state = ' . var_export($this->state, TRUE) . ";\n?>\n"
+				'$state = ' . var_export($this->state, TRUE) . ";\n?>\n",
+				0644
 			);
 		}
 	}
@@ -380,7 +382,7 @@ class sspmod_metarefresh_MetaLoader {
 
 				$content .= "\n" . '?>';
 
-				SimpleSAML_Utilities::writeFile($filename, $content);
+				SimpleSAML_Utilities::writeFile($filename, $content, 0644);
 			} elseif(is_file($filename)) {
 				if(unlink($filename)) {
 					SimpleSAML_Logger::debug('Deleting stale metadata file: ' . $filename);
@@ -443,4 +445,4 @@ class sspmod_metarefresh_MetaLoader {
 
 }
 
-?>
\ No newline at end of file
+?>
