@@ -7,7 +7,6 @@ require_once(dirname(dirname(__FILE__)) . '/libextinc/OAuth.php');
  *
  * @author Andreas Åkre Solberg, <andreas.solberg@uninett.no>, UNINETT AS.
  * @package simpleSAMLphp
- * @version $Id: Consumer.php 3326 2014-01-17 15:40:02Z jaimepc@gmail.com $
  */
 class sspmod_oauth_Consumer {
 	
@@ -79,7 +78,7 @@ class sspmod_oauth_Consumer {
 		parse_str($response_req, $responseParsed);
 		
 		if(array_key_exists('error', $responseParsed))
-			throw new Exception('Error getting request token: ') . $responseParsed['error'];
+			throw new Exception('Error getting request token: ' . $responseParsed['error']);
 			
 		$requestToken = $responseParsed['oauth_token'];
 		$requestTokenSecret = $responseParsed['oauth_token_secret'];
@@ -115,7 +114,7 @@ class sspmod_oauth_Consumer {
 		parse_str($response_acc, $accessResponseParsed);
 		
 		if(array_key_exists('error', $accessResponseParsed))
-			throw new Exception('Error getting request token: ') . $accessResponseParsed['error'];
+			throw new Exception('Error getting request token: ' . $accessResponseParsed['error']);
 		
 		$accessToken = $accessResponseParsed['oauth_token'];
 		$accessTokenSecret = $accessResponseParsed['oauth_token_secret'];
@@ -145,7 +144,7 @@ class sspmod_oauth_Consumer {
 		$context = stream_context_create($opts);
 		$response = file_get_contents($url, FALSE, $context);
 		if ($response === FALSE) {
-			throw new SimpleSAML_Error_Exception('Failed to push definition file to ' . $pushURL);
+			throw new SimpleSAML_Error_Exception('Failed to push definition file to ' . $url);
 		}
 		return $response;
 	}
