@@ -1,16 +1,24 @@
 <?php
 
+/**
+ * WARNING:
+ *
+ * THIS FILE IS DEPRECATED AND WILL BE REMOVED IN FUTURE VERSIONS
+ *
+ * @deprecated
+ */
 
 require_once('../_include.php');
 
 $config = SimpleSAML_Configuration::getInstance();
 $metadata = SimpleSAML_Metadata_MetaDataStorageHandler::getMetadataHandler();
-$session = SimpleSAML_Session::getInstance();
+$session = SimpleSAML_Session::getSessionFromRequest();
+
+SimpleSAML_Logger::warning('The file auth/login-ldapmulti.php is deprecated and will be removed in future versions.');
 
 $ldapconfigfile = $config->getBaseDir() . 'config/ldapmulti.php';
 require_once($ldapconfigfile);
 
-
 SimpleSAML_Logger::info('AUTH - ldap-multi: Accessing auth endpoint login-ldapmulti');
 
 $error = null;
@@ -23,6 +31,8 @@ if (!array_key_exists('RelayState', $_REQUEST)) {
 	throw new SimpleSAML_Error_Error('NORELAYSTATE');
 }
 
+$relaystate = SimpleSAML_Utilities::checkURLAllowed($_REQUEST['RelayState']);
+
 if (isset($_POST['username'])) {
 
 	try {
@@ -50,8 +60,7 @@ if (isset($_POST['username'])) {
 		$attributes = $ldap->getAttributes($dn, $ldapconfig['attributes']);
 						
 		SimpleSAML_Logger::info('AUTH - ldap-multi: '. $_POST['username'] . ' successfully authenticated');
-				
-				
+
 		$session->doLogin('login-ldapmulti');
 		$session->setAttributes($attributes);
 				
@@ -64,19 +73,16 @@ if (isset($_POST['username'])) {
 		 * Also log a specific attribute as set in the config: statistics.authlogattr
 		 */
 		$authlogattr = $config->getValue('statistics.authlogattr', null);
-		if ($authlogattr && array_key_exists($authlogattr, $attributes)) 
+		if ($authlogattr && array_key_exists($authlogattr, $attributes)) {
 			SimpleSAML_Logger::stats('AUTH-login-ldapmulti OK ' . $attributes[$authlogattr][0]);
-		else 
+		} else {
 			SimpleSAML_Logger::stats('AUTH-login-ldapmulti OK');
-				
-				
-		$returnto = $_REQUEST['RelayState'];
-		SimpleSAML_Utilities::redirect($returnto);
+		}
+
+		SimpleSAML_Utilities::redirectTrustedURL($relaystate);
 
 	} catch (Exception $e) {
-		
 		$error = $e->getMessage();
-		
 	}	
 }
 
@@ -84,7 +90,7 @@ if (isset($_POST['username'])) {
 $t = new SimpleSAML_XHTML_Template($config, 'login-ldapmulti.php', 'login');
 
 $t->data['header'] = 'simpleSAMLphp: Enter username and password';	
-$t->data['relaystate'] = $_REQUEST['RelayState'];
+$t->data['relaystate'] = $relaystate;
 $t->data['ldapconfig'] = $ldapmulti;
 $t->data['org'] = $_REQUEST['org'];
 $t->data['error'] = $error;
